@@ -1,6 +1,9 @@
 sim.default <- function(object, x, x1=NULL, num=c(1000, 100),
                         prev = NULL, bootstrap = FALSE, bootfn=NULL,
                         cond.data = NULL, ...) {
+  x <- as.matrix(x)
+  if (!is.null(x1))
+    x1 <- as.matrix(x1)
   if (any(class(object) == "MCMCZelig"))
     num <- nrow(object$coefficients)
   else if (length(num) == 2) {
